HubbleHTTPRequestOptions class

Constructors

HubbleHTTPRequestOptions({Duration receiveTimeout = const Duration(seconds: 20), int redirectCount = 2, bool isProtobuf = false, bool parseJson = true})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isProtobuf → bool
final
parseJson → bool
final
receiveTimeout → Duration
final
redirectCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited