PlatformUtils class

Constructors

PlatformUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

hostOs → String
no setter
isAndroid → bool
no setter
isAndroidWeb → bool
no setter
isDesktop → bool
no setter
isDesktopWeb → bool
no setter
isIOS → bool
no setter
isIOSWeb → bool
no setter
isMobile → bool
no setter
isMobileWeb → bool
no setter
isWeb → bool
no setter
operatingSystem → String
no setter

Static Methods

platormSpecificValue<T>({T? web, T? android, T? ios, required T fallback}) → T
platormSpecificValueNulable<T>({T? web, T? android, T? ios}) → T?