PreferenceKeys class

Constructors

PreferenceKeys()
factory

Properties

accountProfileEmail → String
final
accountProfileFirstName → String
final
accountProfileLastName → String
final
appRatingsCountKey → String
final
appRatingsKey → String
final
appRatingsShownAtKey → String
final
attributedReferrerId → String
final
authSessionIdKey → String
final
final
deviceIdKey → String
final
displayPicture → String
final
firebaseToken → String
final
hapticsEnabled → String
final
hashCode → int
The hash code for this object.
no setterinherited
hubbleRatingKey → String
final
hubbleRemindLaterKey → String
final
inviteLinkKey → String
final
isVoucherInProgress → String
final
lastUpdateNonce → String
final
localAuthEnabledKey → String
final
localAuthPromptedKey → String
final
messages → String
final
numGoalsKey → String
final
onBoardingShownKey → String
final
phoneNumber → String
final
postRedemptionShowAppRatingsKey → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAppLockDialogKey → String
final
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited