PaymentOption enum

Inheritance
Available extensions

Values

phonePe → const PaymentOption
phonePeSimulator → const PaymentOption
gPay → const PaymentOption
payTM → const PaymentOption
bhim → const PaymentOption
cred → const PaymentOption
anyUPIApp → const PaymentOption
collectRequest → const PaymentOption

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isCollectRequest → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upiApp → UPIApp
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PaymentOption>
A constant List of the values in this enum, in order of their declaration.