UPIApp class

Constructors

UPIApp({required String name, required String razorPayIntentName, String? intentScheme, String? intentHost, String? intentPath, String? deeplinkScheme, String? deeplinkHost, String? deeplinkPath, required String androidPackageName, required AssetImage icon, required AssetImage circularIcon, bool supportsIntentLaunch = false, required String backendName, required PaymentOption type, Color iconBackgroundColor = Colors.white, EdgeInsets iconPadding = const EdgeInsets.all(10)})

Properties

androidPackageName → String
final
backendName → String
final
circularIcon → AssetImage
final
deeplinkHost → String?
final
deeplinkPath → String?
final
deeplinkScheme → String?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → AssetImage
final
iconBackgroundColor → Color
final
iconPadding → EdgeInsets
final
intentHost → String?
final
intentPath → String?
final
intentScheme → String?
final
name → String
final
razorPayIntentName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsIntentLaunch → bool
final
type → PaymentOption
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited